#
# spec file for package libndp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libndp
Version:        1.8
Release:        2.5
Summary:        Library for Neighbor Discovery Protocol
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Other
URL:            http://libndp.org/
Source:         http://libndp.org/files/libndp-%{version}.tar.gz
# PATCH-FIX-UPSTREAM libndp-CVE-2024-5564.patch bsc#1225771 mgorse@suse.com -- add a check on the route information option length field.
Patch0:         libndp-CVE-2024-5564.patch
BuildRequires:  pkgconfig

%description
This package contains a library which provides a wrapper for IPv6 Neighbor
Discovery Protocol.  It also provides a tool named ndptool for sending and
receiving NDP messages.

%package -n libndp0
Summary:        Libraries and header files for libndp development
Group:          System/Libraries

%description -n libndp0
This package contains a library which provides a wrapper for IPv6 Neighbor
Discovery Protocol.

%package devel
Summary:        Libraries and header files for libndp development
Group:          Development/Libraries/C and C++
Requires:       libndp0 = %{version}

%description devel
The libndp-devel package contains the header files necessary for developing
programs using libndp.

%prep
%autosetup -p1

%build
%configure \
  --disable-static
%make_build

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libndp0 -p /sbin/ldconfig
%postun -n libndp0 -p /sbin/ldconfig

%files
%license COPYING
%{_bindir}/ndptool
%{_mandir}/man8/ndptool.8%{?ext_man}

%files -n libndp0
%license COPYING
%{_libdir}/libndp.so.*

%files devel
%license COPYING
%{_includedir}/ndp.h
%{_libdir}/libndp.so
%{_libdir}/pkgconfig/libndp.pc

%changelog
* Thu Jun 27 2024 Michael Gorse <mgorse@suse.com>
- Add libndp-CVE-2024-5564.patch: add a check on the route
  information option length field (bsc#1225771 CVE-2024-5564).
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.8:
  * libndp,ndptool: use poll() instead of select()
  * ndptool: avoid static buffer for string in ndptool
  * libndp: avoid static buffer for debug string in ndp_sock_recv()
  * libndp: use thread local variables for static return arguments
  * ndptool: fix printing dnssl lifetime in ndptool
  * ndptool: fix potential memory leak caused by strdup
  * libndp: close sockfd after using to avoid handle leak
* Wed Oct 24 2018 sean@suspend.net
- Update to version 1.7
  * fix socket fd missing for O_CLOEXEC
  * Fix issue where not sending all IPs to an interface
  * typo in ndptool.c fixed
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun May 22 2016 mpluskal@suse.com
- Update to version 1.6 (bsc#979645 CVE-2016-3698):
  * libndp: reject redirect and router advertisements from
    non-link-local
  * libndp: validate the IPv6 hop limit
- Changes for version 1.5:
  * ndptool: validate the IPv6 hop limit
- Small spec file adjustement:
  * Used spec-cleaner
  * Make building more verbose
  * Update describtion of subpackages
  * Use correct cathegory for subpackage
* Mon Jan  5 2015 dimstar@opensuse.org
- Update to version 1.4:
  + libndp: fix buffer overflow in ndp_msg_opt_dnssl_domain().
* Wed Jul  9 2014 dimstar@opensuse.org
- Update to version 1.3:
  + libndp: fix [cppcheck] Undefined behavior: Variable 'buf' is
    used as parameter and destination in s[n]printf().
- No longer bootstrap: the tarball is complete.
- Remove libtool, automake and autoconf BuildRequires: no longer
  needed.
* Wed Jul  9 2014 dimstar@opensuse.org
- Minor cleanups for inclusion into Factory:
  + Shared Library packages must only contain libraries (move
    binary file and man page to main package).
  + Adjust RPM Groups: Productivity/Networking/Other for the main
    package and System/Libraries for the shared library package.
* Sat Feb  8 2014 meissner@suse.com
- library for neighbour discovery, for later use by NetworkManager
